| orisma_dict | R Documentation |
ORISMA ships with a comprehensive normative risk dictionary anchored in four internationally recognised taxonomies:
INSST Instituto Nacional de Seguridad y Salud en el Trabajo (Spain)
ISO 45001:2018 International OHS management system standard
NIOSH National Institute for Occupational Safety and Health (USA)
EU-OSHA European Agency for Safety and Health at Work
The dictionary covers 58 risk categories organised in 6 blocks: A) Safety at work (18), B) Industrial hygiene (8), C) Ergonomics (8), D) Psychosociology (11), E) Biological hazards (5), F) Emerging technologies (8).
# View available dictionaries
orm_dict_list()
# Load the default dictionary
dict <- orm_dict()
# View all categories
orm_dict_categories(dict)
# Add custom terms to a category
dict <- orm_dict_add_terms(dict, "nanomaterials",
c("metal powder", "powder bed"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.